TextureConverter class
Constructors
Properties
- decompressCamera ↔ PerspectiveCamera?
-
getter/setter pair
- decompressScene ↔ Scene?
-
getter/setter pair
- fullscreenQuad ↔ Mesh?
-
getter/setter pair
- fullscreenQuadGeometry ↔ BufferGeometry?
-
getter/setter pair
- fullscreenQuadMaterial ↔ ShaderMaterial?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decompress(
Texture texture, [int? maxTextureSize, Renderer? renderer]) → Texture? - Decompresses hardware/GPU compressed textures into a readable raw pixel DataTexture. Fully compatible across Web, iOS, Android, and Desktop targets.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- CRC32_TABLE → Uint32List
-
final
- PNG_SIGNATURE → Uint8List
-
final
Static Methods
-
concatUint8Arrays(
List< Uint8List> chunks) → Uint8List -
convertTextureToPNG(
Texture texture, [int maxTextureSize = 2048]) → Future< Uint8List?> -
crc32(
Uint8List data) → int -
createPngChunk(
String type, Uint8List data) → Uint8List -
createZipData(
Map< String, Uint8List> files) → Future<Uint8List> -
extractTextureData(
Texture texture, bool embedTextures) → Uint8List? -
getImmediateTextureData(
Texture texture) → Uint8List? -
getMaxTextureSize(
List< Texture?> textures) → Vector2 -
writeUint32BE(
Uint8List target, int offset, int value) → void